# SCA as a Service Helm Chart

This chart bootstraps SCA As A Service deployment on a Kubernetes cluster using Helm package manager.

## Prerequisites

* Kubernetes 1.9+
    * storageClass configured that allows persistent volumes.
* Helm2 or Helm3
* BlackDuck Artifcatory plugin installed in the target JFrog Artifactory
* Add the Synopsys repository to Helm repository
```bash
$ helm repo add synopsys https://sig-repo.synopsys.com/artifactory/sig-cloudnative
```



## Quick Start Parameters

* `name`
* `namespace` -- usually the same as `name`



## Installing the Chart -- Helm 3

### Create the Namespace

NOTE: This chart can be installed in the same namespace as Black Duck instance.

Create this namespace if the namespace has not been created.

```bash
$ SCAAAS_NAMESPACE="scaaas"
$ kubectl create ns ${SCAAAS_NAMESPACE}
```

### Create secret's for tokens

Token for Black Duck instance needs to be configured as secret.

```bash
$ SCAAAS_NAMESPACE="scaaas"
$ kubectl create secret generic ${SCAAAS_NAMESPACE}-scaaas-secret-store --namespace=${SCAAAS_NAMESPACE}  --from-literal=scaaas_blackduck_token=<blackduck_token>
```

### Install the SCA As A Service Chart

```bash
$ SCAAAS_NAME="scaaas" && SCAAAS_NAMESPACE="scaaas"
$ helm install ${SCAAAS_NAME} sca-as-a-sevice/ --namespace ${SCAAAS_NAMESPACE} 
```

> **Tip**: List all releases using `helm list` and list all specified values using `helm get values RELEASE_NAME`

> **Note**: You must not use the `--wait` flag when you install the Helm Chart. `--wait` waits for all pods to become Ready before marking the **Install** as done.


## Uninstalling the Chart

To uninstall/delete the deployment:

```bash
$ helm delete ${SCAAAS_NAME} --namespace ${SCAAAS_NAMESPACE}
```

The command removes all the Kubernetes components associated with the chart and deletes the release.

## Upgrading the Chart

Before upgrading to new version, please make sure to run the below command to pull the latest version of charts from chart museum

```bash
$ helm repo update
```

## Updating the Chart

Updating is a specific type of upgrade which allows for making changes, such as adding ENV variables, to the same version. When updating it is
acceptable to use the `--reuse-values` flag.

To update the deployment:

```bash
$ helm upgrade ${SCAAAS_NAME} sca-as-a-service/ --reuse-values --namespace ${SCAAAS_NAMESPACE}
```

## Configuration

The following table lists the configurable parameters of the SCA As A Service chart and their default values.

### Common Configuration

| Parameter | Description                                                                                                                                                    | Default                                                          |
| --------- |----------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------|
| `registry` | Image repository                                                                                                                                               | `docker.io/blackducksoftware`                                    |
| `imageTag` | Version of SCA AS A Service                                                                                                                                    | `@version@`                                                      |
| `imagePullSecrets` | Reference to one or more secrets to be used when pulling images                                                                                                | `[]`                                                             |
| `enablePersistentStorage` | If true, Black Duck will have persistent storage                                                                                                               | `true`                                                           |
| `storageClass` | Global storage class to be used in all Persistent Volume Claim                                                                                                 |                                                                  |
| `enableLivenessProbe` | If true, Black Duck will have liveness probe                                                                                                                   | `true`                                                           |
| `enableInitContainer` | If true, Black Duck will initialize the required databases                                                                                                     | `true`                                                           |
| `enableIPV6` | If true, IPV6 support will be enabled by setting in the environment variable (this takes priority over environs flag values)                                   | `true`                                                           |
| `environs` | environment variables that need to be added to Black Duck configuration                                                                                        | See [Values for environs](#Values for environs) section for environs configutration |

### Values for environs

This can be configured directly in `values.yaml` or using multiple `--set environs.RABBIT_MQ_PORT=5672`.

| Parameter | Description                                                                                           | Default |
| --------- |-------------------------------------------------------------------------------------------------------|---|
| `RABBIT_MQ_PORT` | Port used for rabbitMQ communication                                                                  | `5672` |
| `BLACKDUCK_SCAAAS_BLACKDUCK_SCHEME` | Protocol to use to connect to Blackduck instance   |   |
| `BLACKDUCK_SCAAAS_BLACKDUCK_HOST` | Name of the Blackduck instance |   |
| `BLACKDUCK_SCAAAS_BLACKDUCK_PORT` | The port on which the Blackduck instance is reachable. |   |

TODO - add links to all possible configuration link 
### Manager Pod Configuration

| Parameter                               | Description                                        | Default |
|-----------------------------------------|----------------------------------------------------| ------- |
| `manager.registry`                      | Image repository to be override at container level |  |
| `manager.replicas`                    | Manager Pod Replica Count                          | `1` |
| `manager.resources.limits.memory`   | Manager container Memory Limit                     | `4608Mi` |
| `manager.resources.requests.memory` | Manager container Memory request                   | `4608Mi` |
| `manager.nodeSelector`              | Manager node labels for pod assignment             | `{}` |
| `manager.tolerations`               | Manager node tolerations for pod assignment        | `[]` |
| `manager.affinity`                  | Manager node affinity for pod assignment           | `{}` |
| `manager.podSecurityContext`        | Manager security context at pod level         | `{}` |
| `manager.securityContext`           | Manager security context at container level   | `{}` |


### Scanner Pod Configuration

| Parameter                           | Description                                        | Default |
|-------------------------------------|----------------------------------------------------| ------- |
| `scanner.registry`                      | Image repository to be override at container level |  |
| `scanner.replicas`                  | Scanner Pod Replica Count                          | `1` |
| `scanner.resources.limits.memory`   | Scanner container Memory Limit                | `4608Mi` |
| `scanner.resources.requests.memory` | Scanner container Memory request              | `4608Mi` |
| `scanner.nodeSelector`          | Scanner node labels for pod assignment        | `{}` |
| `scanner.tolerations`           | Scanner node tolerations for pod assignment   | `[]` |
| `scanner.affinity`              | Scanner node affinity for pod assignment      | `{}` |
| `scanner.podSecurityContext`    | Scanner security context at pod level         | `{}` |
| `scanner.securityContext`       | Scanner security context at container level   | `{}` |


### RabbitMQ Pod Configuration

| Parameter | Description | Default |
| --------- | ----------- | ------- |
| `rabbitmq.registry` | Image repository to be override at container level |  |
| `rabbitmq.imageTag` | Image tag to be override at container level | `@rabbitmqVersion@` |
| `rabbitmq.resources.limits.memory` | RabbitMQ container Memory Limit | `1024Mi` |
| `rabbitmq.resources.requests.memory` | RabbitMQ container Memory request | `1024Mi` |
| `rabbitmq.nodeSelector` | RabbitMQ node labels for pod assignment | `{}` |
| `rabbitmq.tolerations` | RabbitMQ node tolerations for pod assignment | `[]` |
| `rabbitmq.affinity` | RabbitMQ node affinity for pod assignment | `{}` |
| `rabbitmq.podSecurityContext` | RabbitMQ security context at pod level | `{}` |
| `rabbitmq.securityContext` | RabbitMQ security context at container level | `{}` |

## Additional documentation

Please refer to the BlackDuck documentation for BlackDuck installation
https://sig-product-docs.synopsys.com/bundle/bd-hub/page/Install_Kubernetes/InstallingBDHelm.html
